<?php

declare(strict_types=1);

namespace Drupal\Tests\joinup_group\ExistingSite;

use Drupal\Tests\joinup_test\ExistingSite\JoinupExistingSiteTestBase;
use Drupal\Tests\token\Functional\TokenTestTrait;

/**
 * Tests the rdf entity tokens for solutions, releases and distributions.
 */
class GroupTokensTest extends JoinupExistingSiteTestBase {

  use TokenTestTrait;

  /**
   * Tests tokens defined by joinup_group.
   */
  public function testGroupDefinedTokens(): void {
    $collection = $this->createRdfEntity([
      'rid' => 'collection',
      'label' => $this->randomString(),
      'field_ar_state' => 'published',
    ]);

    $solution = $this->createRdfEntity([
      'rid' => 'solution',
      'field_is_state' => 'published',
      'label' => $this->randomString(),
      'collection' => $collection->id(),
    ]);

    $standalone_distribution = $this->createNode([
      'type' => 'distribution',
      'title' => $this->randomString(),
      'og_audience' => $solution->id(),
      'field_state' => 'published',
    ]);

    $release = $this->createNode([
      'type' => 'release',
      'og_audience' => $solution->id(),
    ]);

    $release_distribution = $this->createNode([
      'type' => 'distribution',
      'title' => $this->randomString(),
      'og_audience' => $solution->id(),
      'field_state' => 'published',
      'release' => $release->id(),
    ]);

    $entities_to_test = [
      'rdf_entity' => [
        $solution,
      ],
      'node' => [
        $release,
        $release_distribution,
        $standalone_distribution,
      ],
    ];

    $tokens = [
      'parent_collection' => $collection->label(),
      'parent_collection:id:value' => $collection->id(),
      'parent_collection:label:value' => $collection->label(),
      // URL::toString generates an aliased path.
      'parent_collection:url' => $collection->toUrl('canonical')->toString(),
    ];

    foreach ($entities_to_test as $entity_type_id => $entities) {
      foreach ($entities as $entity) {
        $data = [$entity_type_id => $entity];
        $this->assertTokens($entity_type_id, $data, $tokens);
      }
    }
  }

}
